Module sync

Module sync 

Thread-safe KAdmin interface to kadm5

This is a thread-safe wrapper over crate::kadmin::KAdmin. It accomplishes this by spawning a separate thread with a non-sync crate::kadmin::KAdmin instance, and sending operations and results over a channel.

The APIs between this wrapper and the underlying crate::kadmin::KAdmin are the same, and wrapped and the KAdminImpl trait.

Structs

KAdmin
Thread-safe interface to kadm5
KAdminBuilder
KAdmin builder