KAdminBuilder

Struct KAdminBuilder 

pub struct KAdminBuilder { /* private fields */ }
KAdmin builder

Implementations

Source

impl KAdminBuilder

pub fn new(variant: KAdm5Variant) -> Self

Create a new KAdminBuilder instance

pub fn params(self, params: Params) -> Self

Provide additional Params to this KAdmin instance

pub fn db_args(self, db_args: DbArgs) -> Self

Provide additional DbArgs to this KAdmin instance

pub fn api_version(self, api_version: KAdminApiVersion) -> Self

Set the kadm5 API version to use. See KAdminApiVersion for details

pub fn library_path<S: AsRef<OsStr>>(self, library_path: S) -> Self

Set the path from where to load the kadm5 library

pub fn with_password(self, client_name: &str, password: &str) -> Result<KAdmin>

Construct a KAdmin object from this builder using a client name (usually a principal name) and a password

pub fn with_keytab( self, client_name: Option<&str>, keytab: Option<&str>, ) -> Result<KAdmin>

Construct a KAdmin object from this builder using an optional client name (usually a principal name) and an optional keytab

If no client name is provided, host/hostname will be used

If no keytab is provided, the default keytab will be used

pub fn with_ccache( self, client_name: Option<&str>, ccache_name: Option<&str>, ) -> Result<KAdmin>

Construct a KAdmin object from this builder using an optional client name (usually a principal name) and an optional credentials cache name

If no client name is provided, the default principal from the credentials cache will be used

If no credentials cache name is provided, the default credentials cache will be used

pub fn with_anonymous(self, client_name: &str) -> Result<KAdmin>

Not implemented

pub fn with_local(self) -> Result<KAdmin>

Available on mit_server or heimdal_server only.

Construct a KAdmin object from this builder for local database manipulation.

Only available on server-side libraries.