#[non_exhaustive]pub enum Error {
Show 16 variants
Kerberos {
code: i64,
message: String,
},
KAdmin {
code: i64,
message: String,
},
EncryptionTypeConversion,
SaltTypeConversion,
NullPointerDereference,
CStringConversion(IntoStringError),
CStringImportFromVec(FromVecWithNulError),
StringConversion(NulError),
ThreadSendError,
ThreadRecvError(RecvError),
TimestampConversion,
DateTimeConversion(TryFromIntError),
DurationConversion(TryFromIntError),
LockError,
LibraryLoadError(Error),
LibraryMismatch(&'static str),
}Expand description
Errors this library can encounter
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Kerberos
Represent a Kerberos error.
Provided are the origin error code plus an error message as
returned by krb5_get_error_message
KAdmin
Represent a kadm5 error.
Provided are the origin error code plus an error message from the MIT krb5 implementation (which are not exposed via a function)
EncryptionTypeConversion
Conversion to an encryption type failed
SaltTypeConversion
Conversion to a salt type failed
NullPointerDereference
When converting a *c_char to a String, if the provided pointer was NULL, this error
is returned
CStringConversion(IntoStringError)
CStringImportFromVec(FromVecWithNulError)
Couldn’t import a Vec<u8> as a CString
StringConversion(NulError)
ThreadSendError
Failed to send an operation to the sync executor
ThreadRecvError(RecvError)
Failed to receive the result from an operatior from the sync executor
TimestampConversion
Failed to convert a krb5_timestamp to a chrono::DateTime
DateTimeConversion(TryFromIntError)
Failed to convert a chrono::DateTime to a krb5_timestamp
DurationConversion(TryFromIntError)
Failed to convert a Duration to a krb5_deltat
LockError
Failed to acquire crate::kadmin::KADMIN_INIT_LOCK or
crate::context::CONTEXT_INIT_LOCK
LibraryLoadError(Error)
Failed to load the kadm5 library
LibraryMismatch(&'static str)
The library is not compatible with the current operation